==> openshift-model-config-6.3.1-sources.jar: io/fabric8/openshift/api/model/config/v1/AuthenticationStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AuthenticationStatusFluentImpl<A extends AuthenticationStatusFluent<A>> extends BaseFluent<A> implements AuthenticationStatusFluent<A>{
  public AuthenticationStatusFluentImpl() {
  }
  public AuthenticationStatusFluentImpl(AuthenticationStatus instance) {
    this.withIntegratedOAuthMetadata(instance.getIntegratedOAuthMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ConfigMapNameReferenceBuilder integratedOAuthMetadata;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIntegratedOAuthMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata!=null ?this.integratedOAuthMetadata.build():null;
  }
  public ConfigMapNameReference buildIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata!=null ?this.integratedOAuthMetadata.build():null;
  }
  public A withIntegratedOAuthMetadata(ConfigMapNameReference integratedOAuthMetadata) {
    _visitables.get("integratedOAuthMetadata").remove(this.integratedOAuthMetadata);
    if (integratedOAuthMetadata!=null){ this.integratedOAuthMetadata= new ConfigMapNameReferenceBuilder(integratedOAuthMetadata); _visitables.get("integratedOAuthMetadata").add(this.integratedOAuthMetadata);} else { this.integratedOAuthMetadata = null; _visitables.get("integratedOAuthMetadata").remove(this.integratedOAuthMetadata); } return (A) this;
  }
  public Boolean hasIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata != null;
  }
  public A withNewIntegratedOAuthMetadata(String name) {
    return (A)withIntegratedOAuthMetadata(new ConfigMapNameReference(name));
  }
  public AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> withNewIntegratedOAuthMetadata() {
    return new AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNestedImpl();
  }
  public AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> withNewIntegratedOAuthMetadataLike(ConfigMapNameReference item) {
    return new AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNestedImpl(item);
  }
  public AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> editIntegratedOAuthMetadata() {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata());
  }
  public AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> editOrNewIntegratedOAuthMetadata() {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata() != null ? getIntegratedOAuthMetadata(): new ConfigMapNameReferenceBuilder().build());
  }
  public AuthenticationStatusFluent.IntegratedOAuthMetadataNested<A> editOrNewIntegratedOAuthMetadataLike(ConfigMapNameReference item) {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata() != null ? getIntegratedOAuthMetadata(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AuthenticationStatusFluentImpl that = (AuthenticationStatusFluentImpl) o;
    if (integratedOAuthMetadata != null ? !integratedOAuthMetadata.equals(that.integratedOAuthMetadata) :that.integratedOAuthMetadata != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(integratedOAuthMetadata,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (integratedOAuthMetadata != null) { sb.append("integratedOAuthMetadata:"); sb.append(integratedOAuthMetadata + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class IntegratedOAuthMetadataNestedImpl<N> extends ConfigMapNameReferenceFluentImpl<AuthenticationStatusFluent.IntegratedOAuthMetadataNested<N>> implements AuthenticationStatusFluent.IntegratedOAuthMetadataNested<N>,Nested<N>{
    IntegratedOAuthMetadataNestedImpl(ConfigMapNameReference item) {
      this.builder = new ConfigMapNameReferenceBuilder(this, item);
    }
    IntegratedOAuthMetadataNestedImpl() {
      this.builder = new ConfigMapNameReferenceBuilder(this);
    }
    ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) AuthenticationStatusFluentImpl.this.withIntegratedOAuthMetadata(builder.build());
    }
    public N endIntegratedOAuthMetadata() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/AuthenticationStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AuthenticationStatusFluentImpl<A extends AuthenticationStatusFluent<A>> extends BaseFluent<A> implements AuthenticationStatusFluent<A>{
  public AuthenticationStatusFluentImpl() {
  }
  public AuthenticationStatusFluentImpl(AuthenticationStatus instance) {
    if (instance != null) {
      this.withIntegratedOAuthMetadata(instance.getIntegratedOAuthMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ConfigMapNameReferenceBuilder integratedOAuthMetadata;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIntegratedOAuthMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata!=null ?this.integratedOAuthMetadata.build():null;
  }
  public ConfigMapNameReference buildIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata!=null ?this.integratedOAuthMetadata.build():null;
  }
  public A withIntegratedOAuthMetadata(ConfigMapNameReference integratedOAuthMetadata) {
    _visitables.get("integratedOAuthMetadata").remove(this.integratedOAuthMetadata);
    if (integratedOAuthMetadata!=null){ this.integratedOAuthMetadata= new ConfigMapNameReferenceBuilder(integratedOAuthMetadata); _visitables.get("integratedOAuthMetadata").add(this.integratedOAuthMetadata);} else { this.integratedOAuthMetadata = null; _visitables.get("integratedOAuthMetadata").remove(this.integratedOAuthMetadata); } return (A) this;
  }
  public Boolean hasIntegratedOAuthMetadata() {
    return this.integratedOAuthMetadata != null;
  }
  public A withNewIntegratedOAuthMetadata(String name) {
    return (A)withIntegratedOAuthMetadata(new ConfigMapNameReference(name));
  }
  public AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNested<A> withNewIntegratedOAuthMetadata() {
    return new AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNestedImpl();
  }
  public AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNested<A> withNewIntegratedOAuthMetadataLike(ConfigMapNameReference item) {
    return new AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNestedImpl(item);
  }
  public AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNested<A> editIntegratedOAuthMetadata() {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata());
  }
  public AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNested<A> editOrNewIntegratedOAuthMetadata() {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata() != null ? getIntegratedOAuthMetadata(): new ConfigMapNameReferenceBuilder().build());
  }
  public AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNested<A> editOrNewIntegratedOAuthMetadataLike(ConfigMapNameReference item) {
    return withNewIntegratedOAuthMetadataLike(getIntegratedOAuthMetadata() != null ? getIntegratedOAuthMetadata(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuthenticationStatusFluentImpl that = (AuthenticationStatusFluentImpl) o;
    if (!java.util.Objects.equals(integratedOAuthMetadata, that.integratedOAuthMetadata)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(integratedOAuthMetadata,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (integratedOAuthMetadata != null) { sb.append("integratedOAuthMetadata:"); sb.append(integratedOAuthMetadata + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class IntegratedOAuthMetadataNestedImpl<N> extends ConfigMapNameReferenceFluentImpl<AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNested<N>> implements AuthenticationStatusFluentImpl.IntegratedOAuthMetadataNested<N>,Nested<N>{
    IntegratedOAuthMetadataNestedImpl(ConfigMapNameReference item) {
      this.builder = new ConfigMapNameReferenceBuilder(this, item);
    }
    IntegratedOAuthMetadataNestedImpl() {
      this.builder = new ConfigMapNameReferenceBuilder(this);
    }
    ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) AuthenticationStatusFluentImpl.this.withIntegratedOAuthMetadata(builder.build());
    }
    public N endIntegratedOAuthMetadata() {
      return and();
    }
    
  }
  
}
